py5
---

A Python module that makes Processing_ available to the CPython interpreter using JPype_.

All of this code is created by the py5generator project. Do not edit manually!

.. _Processing: https: // github.com/processing/processing
.. _JPype: https: // github.com/jpype-project/jpype
